@@ -35,7 +35,7 @@ from os import path
 from urllib.parse import urlparse
 from zipfile import BadZipFile, ZipFile
 from csv import writer
-from datetime import utcnow
+from datetime import datetime
 from ._constants import *
 
 logger = logging.getLogger(__name__)
@@ -123,11 +123,16 @@ class IndexHandler:
             path: str or pathlike object
             after: format yyyy-mm-dd
             tracked_filings: set of form types, eg: set(["S-3", "S-1"])
+        
+        Returns:
+            dict[key:list]
+            where key is the CIK and list if of the form:
+                [form_type, accession_number, main_file_name, file_date, ?]
         '''
         if len(cik) < 10:
             cik = cik.zfill(10)
         path = self.root_path / "submissions" / ("CIK" + cik + ".json") 
-        new_filings = {}
+        new_filings = {cik: []}
         with open(path, "r") as f:
             j = json.load(f)
             stop_idx = None
@@ -142,11 +147,10 @@ class IndexHandler:
                         stop_idx = r
                         break
                 if stop_idx is not None:
-                    new_filings[j["cik"]] = []
                     filing = j["filings"]["recent"]
                     for idx in range(0, stop_idx, 1):
                         if (filing["form"][idx] in tracked_filings) or (tracked_filings is None):
-                            new_filings[j["cik"]].append(
+                            new_filings[cik].append(
                                [filing["form"][idx],
                                 filing["accessionNumber"][idx].replace("-", ""),
                                 filing["primaryDocument"][idx],
@@ -704,7 +708,7 @@ class Downloader:
         after_2021q2 = "files/investment"
         before_2021q2 = "divisions/investment/13f"
         if (year is None) and (quarter is None):
-            now = utcnow()
+            now = datetime.utcnow()
             year = int(now.year)
             month = int(now.month)
             if (0 < month < 4):
@@ -1106,5 +1110,4 @@ class Downloader:
         adapter = requests.adapters.HTTPAdapter(max_retries=r) 
         session.mount("http://", adapter)
         session.mount("https://", adapter)
-        return session
-
+        return session
\ No newline at end of file
